/**
 * Copyright (c) 2022, Salesforce, Inc.,
 * All rights reserved.
 * For full license text, see the LICENSE.txt file
 */

import { serializeStructuredKey, ingestShape, deepFreeze, buildNetworkSnapshotCachePolicy as buildNetworkSnapshotCachePolicy$2, typeCheckConfig as typeCheckConfig$4, StoreKeyMap, createResourceParams as createResourceParams$4 } from '@luvio/engine';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys$1, create: ObjectCreate$1 } = Object;
const { stringify: JSONStringify$1 } = JSON;
const { isArray: ArrayIsArray$1 } = Array;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys$1(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray$1(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const snapshotRefreshOptions = {
    overrides: {
        headers: {
            'Cache-Control': 'no-cache',
        },
    }
};
/**
 * A deterministic JSON stringify implementation. Heavily adapted from https://github.com/epoberezkin/fast-json-stable-stringify.
 * This is needed because insertion order for JSON.stringify(object) affects output:
 * JSON.stringify({a: 1, b: 2})
 *      "{"a":1,"b":2}"
 * JSON.stringify({b: 2, a: 1})
 *      "{"b":2,"a":1}"
 * @param data Data to be JSON-stringified.
 * @returns JSON.stringified value with consistent ordering of keys.
 */
function stableJSONStringify(node) {
    // This is for Date values.
    if (node && node.toJSON && typeof node.toJSON === 'function') {
        // eslint-disable-next-line no-param-reassign
        node = node.toJSON();
    }
    if (node === undefined) {
        return;
    }
    if (typeof node === 'number') {
        return isFinite(node) ? '' + node : 'null';
    }
    if (typeof node !== 'object') {
        return JSONStringify$1(node);
    }
    let i;
    let out;
    if (ArrayIsArray$1(node)) {
        out = '[';
        for (i = 0; i < node.length; i++) {
            if (i) {
                out += ',';
            }
            out += stableJSONStringify(node[i]) || 'null';
        }
        return out + ']';
    }
    if (node === null) {
        return 'null';
    }
    const keys = ObjectKeys$1(node).sort();
    out = '';
    for (i = 0; i < keys.length; i++) {
        const key = keys[i];
        const value = stableJSONStringify(node[key]);
        if (!value) {
            continue;
        }
        if (out) {
            out += ',';
        }
        out += JSONStringify$1(key) + ':' + value;
    }
    return '{' + out + '}';
}
function generateParamConfigMetadata(name, required, resourceType, typeCheckShape, isArrayShape = false, coerceFn) {
    return {
        name,
        required,
        resourceType,
        typeCheckShape,
        isArrayShape,
        coerceFn,
    };
}
function buildAdapterValidationConfig(displayName, paramsMeta) {
    const required = paramsMeta.filter(p => p.required).map(p => p.name);
    const optional = paramsMeta.filter(p => !p.required).map(p => p.name);
    return {
        displayName,
        parameters: {
            required,
            optional,
        }
    };
}
const keyPrefix = 'data-transform';

const { keys: ObjectKeys, create: ObjectCreate, assign: ObjectAssign } = Object;
const { isArray: ArrayIsArray } = Array;
const { stringify: JSONStringify } = JSON;
function equalsArray(a, b, equalsItem) {
    const aLength = a.length;
    const bLength = b.length;
    if (aLength !== bLength) {
        return false;
    }
    for (let i = 0; i < aLength; i++) {
        if (equalsItem(a[i], b[i]) === false) {
            return false;
        }
    }
    return true;
}
function equalsObject(a, b, equalsProp) {
    const aKeys = ObjectKeys(a).sort();
    const bKeys = ObjectKeys(b).sort();
    const aKeysLength = aKeys.length;
    const bKeysLength = bKeys.length;
    if (aKeysLength !== bKeysLength) {
        return false;
    }
    for (let i = 0; i < aKeys.length; i++) {
        const key = aKeys[i];
        if (key !== bKeys[i]) {
            return false;
        }
        if (equalsProp(a[key], b[key]) === false) {
            return false;
        }
    }
    return true;
}
function createLink(ref) {
    return {
        __ref: serializeStructuredKey(ref),
    };
}

function validate$a(obj, path = 'TransformValidationIssueRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.errorCode !== undefined) {
            const obj_errorCode = obj.errorCode;
            const path_errorCode = path + '.errorCode';
            if (typeof obj_errorCode !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_errorCode + '" (at "' + path_errorCode + '")');
            }
        }
        if (obj.errorMessage !== undefined) {
            const obj_errorMessage = obj.errorMessage;
            const path_errorMessage = path + '.errorMessage';
            if (typeof obj_errorMessage !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_errorMessage + '" (at "' + path_errorMessage + '")');
            }
        }
        const obj_errorSeverity = obj.errorSeverity;
        const path_errorSeverity = path + '.errorSeverity';
        if (typeof obj_errorSeverity !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_errorSeverity + '" (at "' + path_errorSeverity + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const VERSION$8 = "efb82c29d2d2d9ec860406b7caae554d";
function validate$9(obj, path = 'CdpUserRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        if (obj.name !== undefined) {
            const obj_name = obj.name;
            const path_name = path + '.name';
            if (typeof obj_name !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
            }
        }
        if (obj.profilePhotoUrl !== undefined) {
            const obj_profilePhotoUrl = obj.profilePhotoUrl;
            const path_profilePhotoUrl = path + '.profilePhotoUrl';
            if (typeof obj_profilePhotoUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_profilePhotoUrl + '" (at "' + path_profilePhotoUrl + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$b = function CdpUserRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$8,
        private: [],
        selections: [
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'name',
                kind: 'Scalar',
                required: false
            },
            {
                name: 'profilePhotoUrl',
                kind: 'Scalar',
                required: false
            }
        ]
    };
};
function equals$9(existing, incoming) {
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_name = existing.name;
    const incoming_name = incoming.name;
    // if at least one of these optionals is defined
    if (existing_name !== undefined || incoming_name !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_name === undefined || incoming_name === undefined) {
            return false;
        }
        if (!(existing_name === incoming_name)) {
            return false;
        }
    }
    const existing_profilePhotoUrl = existing.profilePhotoUrl;
    const incoming_profilePhotoUrl = incoming.profilePhotoUrl;
    // if at least one of these optionals is defined
    if (existing_profilePhotoUrl !== undefined || incoming_profilePhotoUrl !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_profilePhotoUrl === undefined || incoming_profilePhotoUrl === undefined) {
            return false;
        }
        if (!(existing_profilePhotoUrl === incoming_profilePhotoUrl)) {
            return false;
        }
    }
    return true;
}

const VERSION$7 = "3fd0683a6603c98784b3d4aeb83ea69b";
function validate$8(obj, path = 'BaseActionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_refreshStatusAction = obj.refreshStatusAction;
        const path_refreshStatusAction = path + '.refreshStatusAction';
        if (typeof obj_refreshStatusAction !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_refreshStatusAction + '" (at "' + path_refreshStatusAction + '")');
        }
        const obj_retryAction = obj.retryAction;
        const path_retryAction = path + '.retryAction';
        if (typeof obj_retryAction !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_retryAction + '" (at "' + path_retryAction + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$a = function BaseActionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$7,
        private: [],
        selections: [
            {
                name: 'refreshStatusAction',
                kind: 'Scalar'
            },
            {
                name: 'retryAction',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$8(existing, incoming) {
    const existing_refreshStatusAction = existing.refreshStatusAction;
    const incoming_refreshStatusAction = incoming.refreshStatusAction;
    if (!(existing_refreshStatusAction === incoming_refreshStatusAction)) {
        return false;
    }
    const existing_retryAction = existing.retryAction;
    const incoming_retryAction = incoming.retryAction;
    if (!(existing_retryAction === incoming_retryAction)) {
        return false;
    }
    return true;
}

const VERSION$6 = "2acfba62fd425f0dc2a8b2bcadde2466";
function validate$7(obj, path = 'CdpErrorRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_errorCode = obj.errorCode;
        const path_errorCode = path + '.errorCode';
        if (typeof obj_errorCode !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_errorCode + '" (at "' + path_errorCode + '")');
        }
        const obj_message = obj.message;
        const path_message = path + '.message';
        if (typeof obj_message !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_message + '" (at "' + path_message + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$9 = function CdpErrorRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$6,
        private: [],
        selections: [
            {
                name: 'errorCode',
                kind: 'Scalar'
            },
            {
                name: 'message',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$7(existing, incoming) {
    const existing_errorCode = existing.errorCode;
    const incoming_errorCode = incoming.errorCode;
    if (!(existing_errorCode === incoming_errorCode)) {
        return false;
    }
    const existing_message = existing.message;
    const incoming_message = incoming.message;
    if (!(existing_message === incoming_message)) {
        return false;
    }
    return true;
}

const VERSION$5 = "9570db02ffdff852b102fde54128dc2f";
function validate$6(obj, path = 'ScheduleRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_schedule = obj.schedule;
        const path_schedule = path + '.schedule';
        if (typeof obj_schedule !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_schedule + '" (at "' + path_schedule + '")');
        }
        const obj_url = obj.url;
        const path_url = path + '.url';
        if (typeof obj_url !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$8 = function ScheduleRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$5,
        private: [],
        selections: [
            {
                name: 'schedule',
                kind: 'Scalar'
            },
            {
                name: 'url',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$6(existing, incoming) {
    const existing_schedule = existing.schedule;
    const incoming_schedule = incoming.schedule;
    if (!(existing_schedule === incoming_schedule)) {
        return false;
    }
    const existing_url = existing.url;
    const incoming_url = incoming.url;
    if (!(existing_url === incoming_url)) {
        return false;
    }
    return true;
}

const VERSION$4 = "6ef7bcc16bd2f432497fc85ead97bca0";
function validate$5(obj, path = 'DataTransformDefinitionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_outputDataObjects = obj.outputDataObjects;
        const path_outputDataObjects = path + '.outputDataObjects';
        if (!ArrayIsArray(obj_outputDataObjects)) {
            return new TypeError('Expected "array" but received "' + typeof obj_outputDataObjects + '" (at "' + path_outputDataObjects + '")');
        }
        for (let i = 0; i < obj_outputDataObjects.length; i++) {
            const obj_outputDataObjects_item = obj_outputDataObjects[i];
            const path_outputDataObjects_item = path_outputDataObjects + '[' + i + ']';
            if (typeof obj_outputDataObjects_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_outputDataObjects_item + '" (at "' + path_outputDataObjects_item + '")');
            }
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
        const obj_version = obj.version;
        const path_version = path + '.version';
        if (typeof obj_version !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_version + '" (at "' + path_version + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$4 = 'DataTransformDefinitionRepresentation';
function normalize$3(input, existing, path, luvio, store, timestamp) {
    const input_outputDataObjects = input.outputDataObjects;
    const input_outputDataObjects_id = path.fullPath + '__outputDataObjects';
    for (let i = 0; i < input_outputDataObjects.length; i++) {
        const input_outputDataObjects_item = input_outputDataObjects[i];
        let input_outputDataObjects_item_id = input_outputDataObjects_id + '__' + i;
        input_outputDataObjects[i] = ingest$1(input_outputDataObjects_item, {
            fullPath: input_outputDataObjects_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$7 = function DataTransformDefinitionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$4,
        private: [],
        selections: [
            {
                name: 'outputDataObjects',
                kind: 'Link',
                plural: true,
                fragment: select$4()
            },
            {
                name: 'type',
                kind: 'Scalar'
            },
            {
                name: 'version',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$5(existing, incoming) {
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    const existing_version = existing.version;
    const incoming_version = incoming.version;
    if (!(existing_version === incoming_version)) {
        return false;
    }
    const existing_outputDataObjects = existing.outputDataObjects;
    const incoming_outputDataObjects = incoming.outputDataObjects;
    const equals_outputDataObjects_items = equalsArray(existing_outputDataObjects, incoming_outputDataObjects, (existing_outputDataObjects_item, incoming_outputDataObjects_item) => {
        if (!(existing_outputDataObjects_item.__ref === incoming_outputDataObjects_item.__ref)) {
            return false;
        }
    });
    if (equals_outputDataObjects_items === false) {
        return false;
    }
    return true;
}
const ingest$3 = function DataTransformDefinitionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$5(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 3000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$3, "data-transform", VERSION$4, RepresentationType$4, equals$5);
    return createLink(key);
};
function getTypeCacheKeys$3(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$4,
        mergeable: false
    });
    const input_outputDataObjects_length = input.outputDataObjects.length;
    for (let i = 0; i < input_outputDataObjects_length; i++) {
        getTypeCacheKeys$1(rootKeySet, luvio, input.outputDataObjects[i]);
    }
}

const VERSION$3 = "924b289e2a40b63f6d1307278d60bd26";
function validate$4(obj, path = 'DataTransformRepresentation') {
    const validateCdpAssetBaseRepresentation_validateError = validate$3(obj, path);
    if (validateCdpAssetBaseRepresentation_validateError !== null) {
        return validateCdpAssetBaseRepresentation_validateError;
    }
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_actionUrls = obj.actionUrls;
        const path_actionUrls = path + '.actionUrls';
        const referencepath_actionUrlsValidationError = validate$8(obj_actionUrls, path_actionUrls);
        if (referencepath_actionUrlsValidationError !== null) {
            let message = 'Object doesn\'t match BaseActionRepresentation (at "' + path_actionUrls + '")\n';
            message += referencepath_actionUrlsValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        if (obj.capabilities !== undefined) {
            const obj_capabilities = obj.capabilities;
            const path_capabilities = path + '.capabilities';
            if (typeof obj_capabilities !== 'object' || ArrayIsArray(obj_capabilities) || obj_capabilities === null) {
                return new TypeError('Expected "object" but received "' + typeof obj_capabilities + '" (at "' + path_capabilities + '")');
            }
            const obj_capabilities_keys = ObjectKeys(obj_capabilities);
            for (let i = 0; i < obj_capabilities_keys.length; i++) {
                const key = obj_capabilities_keys[i];
                const obj_capabilities_prop = obj_capabilities[key];
                const path_capabilities_prop = path_capabilities + '["' + key + '"]';
                if (typeof obj_capabilities_prop !== 'boolean') {
                    return new TypeError('Expected "boolean" but received "' + typeof obj_capabilities_prop + '" (at "' + path_capabilities_prop + '")');
                }
            }
        }
        const obj_creationType = obj.creationType;
        const path_creationType = path + '.creationType';
        if (typeof obj_creationType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_creationType + '" (at "' + path_creationType + '")');
        }
        const obj_dataSpaceName = obj.dataSpaceName;
        const path_dataSpaceName = path + '.dataSpaceName';
        if (typeof obj_dataSpaceName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_dataSpaceName + '" (at "' + path_dataSpaceName + '")');
        }
        const obj_definition = obj.definition;
        const path_definition = path + '.definition';
        if (typeof obj_definition !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_definition + '" (at "' + path_definition + '")');
        }
        const obj_description = obj.description;
        const path_description = path + '.description';
        if (typeof obj_description !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_description + '" (at "' + path_description + '")');
        }
        const obj_lastRunDate = obj.lastRunDate;
        const path_lastRunDate = path + '.lastRunDate';
        if (typeof obj_lastRunDate !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_lastRunDate + '" (at "' + path_lastRunDate + '")');
        }
        const obj_lastRunErrorCode = obj.lastRunErrorCode;
        const path_lastRunErrorCode = path + '.lastRunErrorCode';
        const referencepath_lastRunErrorCodeValidationError = validate$7(obj_lastRunErrorCode, path_lastRunErrorCode);
        if (referencepath_lastRunErrorCodeValidationError !== null) {
            let message = 'Object doesn\'t match CdpErrorRepresentation (at "' + path_lastRunErrorCode + '")\n';
            message += referencepath_lastRunErrorCodeValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_lastRunErrorMessage = obj.lastRunErrorMessage;
        const path_lastRunErrorMessage = path + '.lastRunErrorMessage';
        if (typeof obj_lastRunErrorMessage !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_lastRunErrorMessage + '" (at "' + path_lastRunErrorMessage + '")');
        }
        const obj_lastRunStatus = obj.lastRunStatus;
        const path_lastRunStatus = path + '.lastRunStatus';
        if (typeof obj_lastRunStatus !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_lastRunStatus + '" (at "' + path_lastRunStatus + '")');
        }
        const obj_schedule = obj.schedule;
        const path_schedule = path + '.schedule';
        const referencepath_scheduleValidationError = validate$6(obj_schedule, path_schedule);
        if (referencepath_scheduleValidationError !== null) {
            let message = 'Object doesn\'t match ScheduleRepresentation (at "' + path_schedule + '")\n';
            message += referencepath_scheduleValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_status = obj.status;
        const path_status = path + '.status';
        if (typeof obj_status !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_status + '" (at "' + path_status + '")');
        }
        const obj_tags = obj.tags;
        const path_tags = path + '.tags';
        if (typeof obj_tags !== 'object' || ArrayIsArray(obj_tags) || obj_tags === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_tags + '" (at "' + path_tags + '")');
        }
        const obj_tags_keys = ObjectKeys(obj_tags);
        for (let i = 0; i < obj_tags_keys.length; i++) {
            const key = obj_tags_keys[i];
            const obj_tags_prop = obj_tags[key];
            const path_tags_prop = path_tags + '["' + key + '"]';
            if (typeof obj_tags_prop !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_tags_prop + '" (at "' + path_tags_prop + '")');
            }
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
        obj.version;
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$3 = 'DataTransformRepresentation';
function keyBuilder$6(luvio, config) {
    return keyBuilder$5(luvio, config);
}
function keyBuilderFromType$2(luvio, object) {
    return keyBuilderFromType$1(luvio, object);
}
function normalize$2(input, existing, path, luvio, store, timestamp) {
    const input_definition = input.definition;
    const input_definition_id = path.fullPath + '__definition';
    input.definition = ingest$3(input_definition, {
        fullPath: input_definition_id,
        propertyName: 'definition',
        parent: {
            data: input,
            key: path.fullPath,
            existing: existing,
        },
        ttl: path.ttl
    }, luvio, store, timestamp);
    return input;
}
const select$6 = function DataTransformRepresentationSelect() {
    const { selections: CdpAssetBaseRepresentationSelections } = select$5();
    const { selections: BaseActionRepresentation__selections, opaque: BaseActionRepresentation__opaque, } = select$a();
    const { selections: CdpErrorRepresentation__selections, opaque: CdpErrorRepresentation__opaque, } = select$9();
    const { selections: ScheduleRepresentation__selections, opaque: ScheduleRepresentation__opaque, } = select$8();
    return {
        kind: 'Fragment',
        version: VERSION$3,
        private: [],
        selections: [
            ...CdpAssetBaseRepresentationSelections,
            {
                name: 'actionUrls',
                kind: 'Object',
                selections: BaseActionRepresentation__selections
            },
            {
                name: 'capabilities',
                kind: 'Scalar',
                map: true,
                required: false
            },
            {
                name: 'creationType',
                kind: 'Scalar'
            },
            {
                name: 'dataSpaceName',
                kind: 'Scalar'
            },
            {
                name: 'definition',
                kind: 'Link',
                fragment: select$7()
            },
            {
                name: 'description',
                kind: 'Scalar'
            },
            {
                name: 'lastRunDate',
                kind: 'Scalar'
            },
            {
                name: 'lastRunErrorCode',
                kind: 'Object',
                selections: CdpErrorRepresentation__selections
            },
            {
                name: 'lastRunErrorMessage',
                kind: 'Scalar'
            },
            {
                name: 'lastRunStatus',
                kind: 'Scalar'
            },
            {
                name: 'schedule',
                kind: 'Object',
                selections: ScheduleRepresentation__selections
            },
            {
                name: 'status',
                kind: 'Scalar'
            },
            {
                name: 'tags',
                kind: 'Scalar',
                map: true
            },
            {
                name: 'type',
                kind: 'Scalar'
            },
            {
                name: 'version',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$4(existing, incoming) {
    if (equals$3(existing, incoming) === false) {
        return false;
    }
    const existing_creationType = existing.creationType;
    const incoming_creationType = incoming.creationType;
    if (!(existing_creationType === incoming_creationType)) {
        return false;
    }
    const existing_dataSpaceName = existing.dataSpaceName;
    const incoming_dataSpaceName = incoming.dataSpaceName;
    if (!(existing_dataSpaceName === incoming_dataSpaceName)) {
        return false;
    }
    const existing_description = existing.description;
    const incoming_description = incoming.description;
    if (!(existing_description === incoming_description)) {
        return false;
    }
    const existing_lastRunDate = existing.lastRunDate;
    const incoming_lastRunDate = incoming.lastRunDate;
    if (!(existing_lastRunDate === incoming_lastRunDate)) {
        return false;
    }
    const existing_lastRunErrorMessage = existing.lastRunErrorMessage;
    const incoming_lastRunErrorMessage = incoming.lastRunErrorMessage;
    if (!(existing_lastRunErrorMessage === incoming_lastRunErrorMessage)) {
        return false;
    }
    const existing_lastRunStatus = existing.lastRunStatus;
    const incoming_lastRunStatus = incoming.lastRunStatus;
    if (!(existing_lastRunStatus === incoming_lastRunStatus)) {
        return false;
    }
    const existing_status = existing.status;
    const incoming_status = incoming.status;
    if (!(existing_status === incoming_status)) {
        return false;
    }
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    const existing_version = existing.version;
    const incoming_version = incoming.version;
    if (!(existing_version === incoming_version)) {
        return false;
    }
    const existing_actionUrls = existing.actionUrls;
    const incoming_actionUrls = incoming.actionUrls;
    if (!(equals$8(existing_actionUrls, incoming_actionUrls))) {
        return false;
    }
    const existing_capabilities = existing.capabilities;
    const incoming_capabilities = incoming.capabilities;
    // if at least one of these optionals is defined
    if (existing_capabilities !== undefined || incoming_capabilities !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_capabilities === undefined || incoming_capabilities === undefined) {
            return false;
        }
        const equals_capabilities_props = equalsObject(existing_capabilities, incoming_capabilities, (existing_capabilities_prop, incoming_capabilities_prop) => {
            if (!(existing_capabilities_prop === incoming_capabilities_prop)) {
                return false;
            }
        });
        if (equals_capabilities_props === false) {
            return false;
        }
    }
    const existing_definition = existing.definition;
    const incoming_definition = incoming.definition;
    if (!(existing_definition.__ref === incoming_definition.__ref)) {
        return false;
    }
    const existing_lastRunErrorCode = existing.lastRunErrorCode;
    const incoming_lastRunErrorCode = incoming.lastRunErrorCode;
    if (!(equals$7(existing_lastRunErrorCode, incoming_lastRunErrorCode))) {
        return false;
    }
    const existing_schedule = existing.schedule;
    const incoming_schedule = incoming.schedule;
    if (!(equals$6(existing_schedule, incoming_schedule))) {
        return false;
    }
    const existing_tags = existing.tags;
    const incoming_tags = incoming.tags;
    const equals_tags_props = equalsObject(existing_tags, incoming_tags, (existing_tags_prop, incoming_tags_prop) => {
        if (!(existing_tags_prop === incoming_tags_prop)) {
            return false;
        }
    });
    if (equals_tags_props === false) {
        return false;
    }
    return true;
}
const ingest$2 = function DataTransformRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$4(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$2(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 3000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$2, "data-transform", VERSION$3, RepresentationType$3, equals$4);
    return createLink(key);
};
function getTypeCacheKeys$2(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$2(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$2,
        mergeable: false
    });
    getTypeCacheKeys$3(rootKeySet, luvio, input.definition, () => rootKey + "__" + "definition");
}

var DiscriminatorValues;
(function (DiscriminatorValues) {
    DiscriminatorValues["type"] = "type";
})(DiscriminatorValues || (DiscriminatorValues = {}));
const VERSION$2 = "e45ed0cf1759f7e1fe67049f806edc26";
function validate$3(obj, path = 'CdpAssetBaseRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.createdBy !== undefined) {
            const obj_createdBy = obj.createdBy;
            const path_createdBy = path + '.createdBy';
            const referencepath_createdByValidationError = validate$9(obj_createdBy, path_createdBy);
            if (referencepath_createdByValidationError !== null) {
                let message = 'Object doesn\'t match CdpUserRepresentation (at "' + path_createdBy + '")\n';
                message += referencepath_createdByValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        if (obj.createdDate !== undefined) {
            const obj_createdDate = obj.createdDate;
            const path_createdDate = path + '.createdDate';
            if (typeof obj_createdDate !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_createdDate + '" (at "' + path_createdDate + '")');
            }
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        if (obj.label !== undefined) {
            const obj_label = obj.label;
            const path_label = path + '.label';
            if (typeof obj_label !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
            }
        }
        if (obj.lastModifiedBy !== undefined) {
            const obj_lastModifiedBy = obj.lastModifiedBy;
            const path_lastModifiedBy = path + '.lastModifiedBy';
            const referencepath_lastModifiedByValidationError = validate$9(obj_lastModifiedBy, path_lastModifiedBy);
            if (referencepath_lastModifiedByValidationError !== null) {
                let message = 'Object doesn\'t match CdpUserRepresentation (at "' + path_lastModifiedBy + '")\n';
                message += referencepath_lastModifiedByValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        if (obj.lastModifiedDate !== undefined) {
            const obj_lastModifiedDate = obj.lastModifiedDate;
            const path_lastModifiedDate = path + '.lastModifiedDate';
            if (typeof obj_lastModifiedDate !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lastModifiedDate + '" (at "' + path_lastModifiedDate + '")');
            }
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
        if (obj.namespace !== undefined) {
            const obj_namespace = obj.namespace;
            const path_namespace = path + '.namespace';
            if (typeof obj_namespace !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_namespace + '" (at "' + path_namespace + '")');
            }
        }
        if (obj.url !== undefined) {
            const obj_url = obj.url;
            const path_url = path + '.url';
            if (typeof obj_url !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$2 = 'CdpAssetBaseRepresentation';
function keyBuilder$5(luvio, config) {
    return keyPrefix + '::' + RepresentationType$2 + ':' + config.name;
}
function keyBuilderFromType$1(luvio, object) {
    const keyParams = {
        name: object.name
    };
    return keyBuilder$5(luvio, keyParams);
}
const select$5 = function CdpAssetBaseRepresentationSelect() {
    const { selections: CdpUserRepresentation__selections, opaque: CdpUserRepresentation__opaque, } = select$b();
    return {
        kind: 'Fragment',
        version: VERSION$2,
        private: [],
        selections: [
            {
                name: 'createdBy',
                kind: 'Object',
                selections: CdpUserRepresentation__selections,
                required: false
            },
            {
                name: 'createdDate',
                kind: 'Scalar',
                required: false
            },
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar',
                required: false
            },
            {
                name: 'lastModifiedBy',
                kind: 'Object',
                selections: CdpUserRepresentation__selections,
                required: false
            },
            {
                name: 'lastModifiedDate',
                kind: 'Scalar',
                required: false
            },
            {
                name: 'name',
                kind: 'Scalar'
            },
            {
                name: 'namespace',
                kind: 'Scalar',
                required: false
            },
            {
                name: 'url',
                kind: 'Scalar',
                required: false
            }
        ]
    };
};
function equals$3(existing, incoming) {
    const existing_createdDate = existing.createdDate;
    const incoming_createdDate = incoming.createdDate;
    // if at least one of these optionals is defined
    if (existing_createdDate !== undefined || incoming_createdDate !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_createdDate === undefined || incoming_createdDate === undefined) {
            return false;
        }
        if (!(existing_createdDate === incoming_createdDate)) {
            return false;
        }
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    // if at least one of these optionals is defined
    if (existing_label !== undefined || incoming_label !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_label === undefined || incoming_label === undefined) {
            return false;
        }
        if (!(existing_label === incoming_label)) {
            return false;
        }
    }
    const existing_lastModifiedDate = existing.lastModifiedDate;
    const incoming_lastModifiedDate = incoming.lastModifiedDate;
    // if at least one of these optionals is defined
    if (existing_lastModifiedDate !== undefined || incoming_lastModifiedDate !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_lastModifiedDate === undefined || incoming_lastModifiedDate === undefined) {
            return false;
        }
        if (!(existing_lastModifiedDate === incoming_lastModifiedDate)) {
            return false;
        }
    }
    const existing_name = existing.name;
    const incoming_name = incoming.name;
    if (!(existing_name === incoming_name)) {
        return false;
    }
    const existing_namespace = existing.namespace;
    const incoming_namespace = incoming.namespace;
    // if at least one of these optionals is defined
    if (existing_namespace !== undefined || incoming_namespace !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_namespace === undefined || incoming_namespace === undefined) {
            return false;
        }
        if (!(existing_namespace === incoming_namespace)) {
            return false;
        }
    }
    const existing_url = existing.url;
    const incoming_url = incoming.url;
    // if at least one of these optionals is defined
    if (existing_url !== undefined || incoming_url !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_url === undefined || incoming_url === undefined) {
            return false;
        }
        if (!(existing_url === incoming_url)) {
            return false;
        }
    }
    const existing_createdBy = existing.createdBy;
    const incoming_createdBy = incoming.createdBy;
    // if at least one of these optionals is defined
    if (existing_createdBy !== undefined || incoming_createdBy !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_createdBy === undefined || incoming_createdBy === undefined) {
            return false;
        }
        if (!(equals$9(existing_createdBy, incoming_createdBy))) {
            return false;
        }
    }
    const existing_lastModifiedBy = existing.lastModifiedBy;
    const incoming_lastModifiedBy = incoming.lastModifiedBy;
    // if at least one of these optionals is defined
    if (existing_lastModifiedBy !== undefined || incoming_lastModifiedBy !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_lastModifiedBy === undefined || incoming_lastModifiedBy === undefined) {
            return false;
        }
        if (!(equals$9(existing_lastModifiedBy, incoming_lastModifiedBy))) {
            return false;
        }
    }
    return true;
}

function validate$2(obj, path = 'DataObjectFieldRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_isPrimaryKey = obj.isPrimaryKey;
        const path_isPrimaryKey = path + '.isPrimaryKey';
        if (typeof obj_isPrimaryKey !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isPrimaryKey + '" (at "' + path_isPrimaryKey + '")');
        }
        const obj_keyQualifierField = obj.keyQualifierField;
        const path_keyQualifierField = path + '.keyQualifierField';
        if (typeof obj_keyQualifierField !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_keyQualifierField + '" (at "' + path_keyQualifierField + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function equals$2(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}

const VERSION$1 = "225283ac9b2f9ab35452025c5c47ac83";
function validate$1(obj, path = 'DataObjectRepresentation') {
    const validateCdpAssetBaseRepresentation_validateError = validate$3(obj, path);
    if (validateCdpAssetBaseRepresentation_validateError !== null) {
        return validateCdpAssetBaseRepresentation_validateError;
    }
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_category = obj.category;
        const path_category = path + '.category';
        if (typeof obj_category !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_category + '" (at "' + path_category + '")');
        }
        if (obj.eventDateTimeFieldName !== undefined) {
            const obj_eventDateTimeFieldName = obj.eventDateTimeFieldName;
            const path_eventDateTimeFieldName = path + '.eventDateTimeFieldName';
            if (typeof obj_eventDateTimeFieldName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_eventDateTimeFieldName + '" (at "' + path_eventDateTimeFieldName + '")');
            }
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (!ArrayIsArray(obj_fields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        for (let i = 0; i < obj_fields.length; i++) {
            const obj_fields_item = obj_fields[i];
            const path_fields_item = path_fields + '[' + i + ']';
            const referencepath_fields_itemValidationError = validate$2(obj_fields_item, path_fields_item);
            if (referencepath_fields_itemValidationError !== null) {
                let message = 'Object doesn\'t match DataObjectFieldRepresentation (at "' + path_fields_item + '")\n';
                message += referencepath_fields_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        if (obj.recordModifiedFieldName !== undefined) {
            const obj_recordModifiedFieldName = obj.recordModifiedFieldName;
            const path_recordModifiedFieldName = path + '.recordModifiedFieldName';
            if (typeof obj_recordModifiedFieldName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordModifiedFieldName + '" (at "' + path_recordModifiedFieldName + '")');
            }
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$1 = 'DataObjectRepresentation';
function keyBuilderFromType(luvio, object) {
    return keyBuilderFromType$1(luvio, object);
}
function normalize$1(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$4 = function DataObjectRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1,
        private: [],
        opaque: true
    };
};
function equals$1(existing, incoming) {
    if (equals$3(existing, incoming) === false) {
        return false;
    }
    const existing_category = existing.category;
    const incoming_category = incoming.category;
    if (!(existing_category === incoming_category)) {
        return false;
    }
    const existing_eventDateTimeFieldName = existing.eventDateTimeFieldName;
    const incoming_eventDateTimeFieldName = incoming.eventDateTimeFieldName;
    // if at least one of these optionals is defined
    if (existing_eventDateTimeFieldName !== undefined || incoming_eventDateTimeFieldName !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_eventDateTimeFieldName === undefined || incoming_eventDateTimeFieldName === undefined) {
            return false;
        }
        if (!(existing_eventDateTimeFieldName === incoming_eventDateTimeFieldName)) {
            return false;
        }
    }
    const existing_recordModifiedFieldName = existing.recordModifiedFieldName;
    const incoming_recordModifiedFieldName = incoming.recordModifiedFieldName;
    // if at least one of these optionals is defined
    if (existing_recordModifiedFieldName !== undefined || incoming_recordModifiedFieldName !== undefined) {
        // if one of these is not defined we know the other is defined and therefore
        // not equal
        if (existing_recordModifiedFieldName === undefined || incoming_recordModifiedFieldName === undefined) {
            return false;
        }
        if (!(existing_recordModifiedFieldName === incoming_recordModifiedFieldName)) {
            return false;
        }
    }
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    const existing_fields = existing.fields;
    const incoming_fields = incoming.fields;
    const equals_fields_items = equalsArray(existing_fields, incoming_fields, (existing_fields_item, incoming_fields_item) => {
        if (!(equals$2(existing_fields_item, incoming_fields_item))) {
            return false;
        }
    });
    if (equals_fields_items === false) {
        return false;
    }
    return true;
}
const ingest$1 = function DataObjectRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 3000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$1, "data-transform", VERSION$1, RepresentationType$1, equals$1);
    return createLink(key);
};
function getTypeCacheKeys$1(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$2,
        mergeable: false
    });
}

const VERSION = "21a4cd3206473ce28645099a11735bc6";
function validate(obj, path = 'DataTransformValidationRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.issues !== undefined) {
            const obj_issues = obj.issues;
            const path_issues = path + '.issues';
            if (!ArrayIsArray(obj_issues)) {
                return new TypeError('Expected "array" but received "' + typeof obj_issues + '" (at "' + path_issues + '")');
            }
            for (let i = 0; i < obj_issues.length; i++) {
                const obj_issues_item = obj_issues[i];
                const path_issues_item = path_issues + '[' + i + ']';
                const referencepath_issues_itemValidationError = validate$a(obj_issues_item, path_issues_item);
                if (referencepath_issues_itemValidationError !== null) {
                    let message = 'Object doesn\'t match TransformValidationIssueRepresentation (at "' + path_issues_item + '")\n';
                    message += referencepath_issues_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                    return new TypeError(message);
                }
            }
        }
        if (obj.outputDataObjects !== undefined) {
            const obj_outputDataObjects = obj.outputDataObjects;
            const path_outputDataObjects = path + '.outputDataObjects';
            if (!ArrayIsArray(obj_outputDataObjects)) {
                return new TypeError('Expected "array" but received "' + typeof obj_outputDataObjects + '" (at "' + path_outputDataObjects + '")');
            }
            for (let i = 0; i < obj_outputDataObjects.length; i++) {
                const obj_outputDataObjects_item = obj_outputDataObjects[i];
                const path_outputDataObjects_item = path_outputDataObjects + '[' + i + ']';
                const referencepath_outputDataObjects_itemValidationError = validate$1(obj_outputDataObjects_item, path_outputDataObjects_item);
                if (referencepath_outputDataObjects_itemValidationError !== null) {
                    let message = 'Object doesn\'t match DataObjectRepresentation (at "' + path_outputDataObjects_item + '")\n';
                    message += referencepath_outputDataObjects_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                    return new TypeError(message);
                }
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType = 'DataTransformValidationRepresentation';
function normalize(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$3 = function DataTransformValidationRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION,
        private: [],
        opaque: true
    };
};
function equals(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest = function DataTransformValidationRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 3000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize, "data-transform", VERSION, RepresentationType, equals);
    return createLink(key);
};
function getTypeCacheKeys(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType,
        mergeable: false
    });
}

function select$2(luvio, params) {
    return select$3();
}
function keyBuilder$4(luvio, params) {
    return keyPrefix + '::DataTransformValidationRepresentation:(' + stableJSONStringify(params.body.capabilities) + '::' + 'creationType:' + params.body.creationType + '::' + (params.body.currencyIsoCode === undefined ? 'currencyIsoCode' : 'currencyIsoCode:' + params.body.currencyIsoCode) + '::' + (params.body.dataSpaceName === undefined ? 'dataSpaceName' : 'dataSpaceName:' + params.body.dataSpaceName) + '::' + stableJSONStringify(params.body.definition) + '::' + (params.body.description === undefined ? 'description' : 'description:' + params.body.description) + '::' + (params.body.label === undefined ? 'label' : 'label:' + params.body.label) + '::' + (params.body.name === undefined ? 'name' : 'name:' + params.body.name) + '::' + (params.body.primarySource === undefined ? 'primarySource' : 'primarySource:' + params.body.primarySource) + '::' + stableJSONStringify(params.body.tags) + '::' + 'type:' + params.body.type + ')';
}
function getResponseCacheKeys$3(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys(storeKeyMap, luvio, response, () => keyBuilder$4(luvio, resourceParams));
}
function ingestSuccess$2(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$4(luvio, resourceParams);
    luvio.storeIngest(key, ingest, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$2(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$1(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$4(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$3(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v65.0',
        basePath: '/ssot/data-transforms-validation',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$3 = 'validateDataTransforms';
const validateDataTransforms_ConfigPropertyMetadata = [
    generateParamConfigMetadata('capabilities', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('creationType', true, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('currencyIsoCode', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('dataSpaceName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('definition', true, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('description', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('label', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('name', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('primarySource', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('tags', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('type', true, 2 /* Body */, 0 /* String */),
];
const validateDataTransforms_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$3, validateDataTransforms_ConfigPropertyMetadata);
const createResourceParams$3 = /*#__PURE__*/ createResourceParams$4(validateDataTransforms_ConfigPropertyMetadata);
function keyBuilder$3(luvio, config) {
    const resourceParams = createResourceParams$3(config);
    return keyBuilder$4(luvio, resourceParams);
}
function typeCheckConfig$3(untrustedConfig) {
    const config = {};
    typeCheckConfig$4(untrustedConfig, config, validateDataTransforms_ConfigPropertyMetadata);
    const untrustedConfig_capabilities = untrustedConfig.capabilities;
    if (untrustedIsObject(untrustedConfig_capabilities)) {
        const untrustedConfig_capabilities_object = {};
        const untrustedConfig_capabilities_keys = Object.keys(untrustedConfig_capabilities);
        for (let i = 0, arrayLength = untrustedConfig_capabilities_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_capabilities_keys[i];
            const untrustedConfig_capabilities_prop = untrustedConfig_capabilities[key];
            if (typeof untrustedConfig_capabilities_prop === 'boolean') {
                if (untrustedConfig_capabilities_object !== undefined) {
                    untrustedConfig_capabilities_object[key] = untrustedConfig_capabilities_prop;
                }
            }
        }
        if (untrustedConfig_capabilities_object !== undefined && Object.keys(untrustedConfig_capabilities_object).length >= 0) {
            config.capabilities = untrustedConfig_capabilities_object;
        }
    }
    const untrustedConfig_definition = untrustedConfig.definition;
    if (untrustedIsObject(untrustedConfig_definition)) {
        const untrustedConfig_definition_object = {};
        const untrustedConfig_definition_keys = Object.keys(untrustedConfig_definition);
        for (let i = 0, arrayLength = untrustedConfig_definition_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_definition_keys[i];
            const untrustedConfig_definition_prop = untrustedConfig_definition[key];
            if (untrustedConfig_definition_object !== undefined) {
                untrustedConfig_definition_object[key] = untrustedConfig_definition_prop;
            }
        }
        if (untrustedConfig_definition_object !== undefined && Object.keys(untrustedConfig_definition_object).length >= 0) {
            config.definition = untrustedConfig_definition_object;
        }
    }
    const untrustedConfig_tags = untrustedConfig.tags;
    if (untrustedIsObject(untrustedConfig_tags)) {
        const untrustedConfig_tags_object = {};
        const untrustedConfig_tags_keys = Object.keys(untrustedConfig_tags);
        for (let i = 0, arrayLength = untrustedConfig_tags_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_tags_keys[i];
            const untrustedConfig_tags_prop = untrustedConfig_tags[key];
            if (typeof untrustedConfig_tags_prop === 'string') {
                if (untrustedConfig_tags_object !== undefined) {
                    untrustedConfig_tags_object[key] = untrustedConfig_tags_prop;
                }
            }
        }
        if (untrustedConfig_tags_object !== undefined && Object.keys(untrustedConfig_tags_object).length >= 0) {
            config.tags = untrustedConfig_tags_object;
        }
    }
    return config;
}
function validateAdapterConfig$3(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$3(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$1(luvio, config) {
    createResourceParams$3(config);
    return select$2();
}
function onFetchResponseSuccess$1(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$2(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$3(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$1(luvio, config, resourceParams, response) {
    const snapshot = ingestError$1(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$3(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$3(luvio, config, options) {
    const resourceParams = createResourceParams$3(config);
    const request = createResourceRequest$3(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$1(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$3(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$1(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$1(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$2(context, coercedAdapterRequestContext, buildNetworkSnapshot$3, 'get', false);
}
function buildCachedSnapshotCachePolicy$1(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$3(luvio, config),
        node: adapterFragment$1(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$3(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const validateDataTransformsAdapterFactory = (luvio) => function dataTransform__validateDataTransforms(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$3(untrustedConfig, validateDataTransforms_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$1, buildNetworkSnapshotCachePolicy$1);
};

function select$1(luvio, params) {
    return select$6();
}
function getResponseCacheKeys$2(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$2(storeKeyMap, luvio, response);
}
function ingestSuccess$1(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType$2(luvio, body);
    luvio.storeIngest(key, ingest$2, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1(),
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function createResourceRequest$2(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v65.0',
        basePath: '/ssot/data-transforms',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$2 = 'createDataTransform';
const createDataTransform_ConfigPropertyMetadata = [
    generateParamConfigMetadata('filterGroup', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('capabilities', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('creationType', true, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('currencyIsoCode', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('dataSpaceName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('definition', true, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('description', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('label', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('name', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('primarySource', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('tags', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('type', true, 2 /* Body */, 0 /* String */),
];
const createDataTransform_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$2, createDataTransform_ConfigPropertyMetadata);
const createResourceParams$2 = /*#__PURE__*/ createResourceParams$4(createDataTransform_ConfigPropertyMetadata);
function typeCheckConfig$2(untrustedConfig) {
    const config = {};
    typeCheckConfig$4(untrustedConfig, config, createDataTransform_ConfigPropertyMetadata);
    const untrustedConfig_capabilities = untrustedConfig.capabilities;
    if (untrustedIsObject(untrustedConfig_capabilities)) {
        const untrustedConfig_capabilities_object = {};
        const untrustedConfig_capabilities_keys = Object.keys(untrustedConfig_capabilities);
        for (let i = 0, arrayLength = untrustedConfig_capabilities_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_capabilities_keys[i];
            const untrustedConfig_capabilities_prop = untrustedConfig_capabilities[key];
            if (typeof untrustedConfig_capabilities_prop === 'boolean') {
                if (untrustedConfig_capabilities_object !== undefined) {
                    untrustedConfig_capabilities_object[key] = untrustedConfig_capabilities_prop;
                }
            }
        }
        if (untrustedConfig_capabilities_object !== undefined && Object.keys(untrustedConfig_capabilities_object).length >= 0) {
            config.capabilities = untrustedConfig_capabilities_object;
        }
    }
    const untrustedConfig_definition = untrustedConfig.definition;
    if (untrustedIsObject(untrustedConfig_definition)) {
        const untrustedConfig_definition_object = {};
        const untrustedConfig_definition_keys = Object.keys(untrustedConfig_definition);
        for (let i = 0, arrayLength = untrustedConfig_definition_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_definition_keys[i];
            const untrustedConfig_definition_prop = untrustedConfig_definition[key];
            if (untrustedConfig_definition_object !== undefined) {
                untrustedConfig_definition_object[key] = untrustedConfig_definition_prop;
            }
        }
        if (untrustedConfig_definition_object !== undefined && Object.keys(untrustedConfig_definition_object).length >= 0) {
            config.definition = untrustedConfig_definition_object;
        }
    }
    const untrustedConfig_tags = untrustedConfig.tags;
    if (untrustedIsObject(untrustedConfig_tags)) {
        const untrustedConfig_tags_object = {};
        const untrustedConfig_tags_keys = Object.keys(untrustedConfig_tags);
        for (let i = 0, arrayLength = untrustedConfig_tags_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_tags_keys[i];
            const untrustedConfig_tags_prop = untrustedConfig_tags[key];
            if (typeof untrustedConfig_tags_prop === 'string') {
                if (untrustedConfig_tags_object !== undefined) {
                    untrustedConfig_tags_object[key] = untrustedConfig_tags_prop;
                }
            }
        }
        if (untrustedConfig_tags_object !== undefined && Object.keys(untrustedConfig_tags_object).length >= 0) {
            config.tags = untrustedConfig_tags_object;
        }
    }
    return config;
}
function validateAdapterConfig$2(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$2(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$2(luvio, config, options) {
    const resourceParams = createResourceParams$2(config);
    const request = createResourceRequest$2(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$1(luvio, resourceParams, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$2(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const createDataTransformAdapterFactory = (luvio) => {
    return function createDataTransform(untrustedConfig) {
        const config = validateAdapterConfig$2(untrustedConfig, createDataTransform_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error('Invalid config for "createDataTransform"');
        }
        return buildNetworkSnapshot$2(luvio, config);
    };
};

function select(luvio, params) {
    return select$6();
}
function keyBuilder$2(luvio, params) {
    return keyBuilder$6(luvio, {
        name: params.urlParams.dataTransformNameOrId
    });
}
function getResponseCacheKeys$1(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$2(storeKeyMap, luvio, response);
}
function ingestSuccess(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$2(luvio, resourceParams);
    luvio.storeIngest(key, ingest$2, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$2(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$1(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v65.0',
        basePath: '/ssot/data-transforms/' + config.urlParams.dataTransformNameOrId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$1 = 'getDataTransform';
const getDataTransform_ConfigPropertyMetadata = [
    generateParamConfigMetadata('dataTransformNameOrId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('filterGroup', false, 1 /* QueryParameter */, 0 /* String */),
];
const getDataTransform_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$1, getDataTransform_ConfigPropertyMetadata);
const createResourceParams$1 = /*#__PURE__*/ createResourceParams$4(getDataTransform_ConfigPropertyMetadata);
function keyBuilder$1(luvio, config) {
    const resourceParams = createResourceParams$1(config);
    return keyBuilder$2(luvio, resourceParams);
}
function typeCheckConfig$1(untrustedConfig) {
    const config = {};
    typeCheckConfig$4(untrustedConfig, config, getDataTransform_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$1(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$1(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment(luvio, config) {
    createResourceParams$1(config);
    return select();
}
function onFetchResponseSuccess(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError(luvio, config, resourceParams, response) {
    const snapshot = ingestError(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$1(luvio, config, options) {
    const resourceParams = createResourceParams$1(config);
    const request = createResourceRequest$1(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$1(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$2(context, coercedAdapterRequestContext, buildNetworkSnapshot$1, undefined, false);
}
function buildCachedSnapshotCachePolicy(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1(luvio, config),
        node: adapterFragment(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$1(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getDataTransformAdapterFactory = (luvio) => function dataTransform__getDataTransform(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$1(untrustedConfig, getDataTransform_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy, buildNetworkSnapshotCachePolicy);
};

function keyBuilder(luvio, params) {
    return keyBuilder$6(luvio, {
        name: params.urlParams.dataTransformNameOrId
    });
}
function getResponseCacheKeys(cacheKeyMap, luvio, resourceParams) {
    const key = keyBuilder(luvio, resourceParams);
    cacheKeyMap.set(key, {
        namespace: keyPrefix,
        representationName: RepresentationType$3,
        mergeable: false
    });
}
function evictSuccess(luvio, resourceParams) {
    const key = keyBuilder(luvio, resourceParams);
    luvio.storeEvict(key);
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v65.0',
        basePath: '/ssot/data-transforms/' + config.urlParams.dataTransformNameOrId + '',
        method: 'delete',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName = 'deleteDataTransform';
const deleteDataTransform_ConfigPropertyMetadata = [
    generateParamConfigMetadata('dataTransformNameOrId', true, 0 /* UrlParameter */, 0 /* String */),
];
const deleteDataTransform_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName, deleteDataTransform_ConfigPropertyMetadata);
const createResourceParams = /*#__PURE__*/ createResourceParams$4(deleteDataTransform_ConfigPropertyMetadata);
function typeCheckConfig(untrustedConfig) {
    const config = {};
    typeCheckConfig$4(untrustedConfig, config, deleteDataTransform_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot(luvio, config, options) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then(() => {
        return luvio.handleSuccessResponse(() => {
            evictSuccess(luvio, resourceParams);
            return luvio.storeBroadcast();
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys(cache, luvio, resourceParams);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const deleteDataTransformAdapterFactory = (luvio) => {
    return function dataTransformdeleteDataTransform(untrustedConfig) {
        const config = validateAdapterConfig(untrustedConfig, deleteDataTransform_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error(`Invalid config for "${adapterName}"`);
        }
        return buildNetworkSnapshot(luvio, config);
    };
};

export { createDataTransformAdapterFactory, deleteDataTransformAdapterFactory, getDataTransformAdapterFactory, validateDataTransformsAdapterFactory };
